@@ -214,6 +214,7 @@ parse_rss_items (TotemPlParser *parser, const char *uri, xml_node_t *parent)
 				 TOTEM_PL_PARSER_FIELD_PUB_DATE, pub_date,
 				 TOTEM_PL_PARSER_FIELD_COPYRIGHT, copyright,
 				 TOTEM_PL_PARSER_FIELD_IMAGE_URI, img,
+				 TOTEM_PL_PARSER_FIELD_CONTACT, contact,
 				 NULL);
 
 	for (node = parent->child; node != NULL; node = node->next) {
@@ -359,11 +360,11 @@ totem_pl_parser_add_zune (TotemPlParser *parser,
 static TotemPlParserResult
 parse_atom_entry (TotemPlParser *parser, xml_node_t *parent)
 {
-	const char *title, *author, *img, *uri, *filesize;
+	const char *title, *author, *uri, *filesize;
 	const char *copyright, *pub_date, *description;
 	xml_node_t *node;
 
-	title = author = img = uri = filesize = NULL;
+	title = author = uri = filesize = NULL;
 	copyright = pub_date = description = NULL;
 
 	for (node = parent->child; node != NULL; node = node->next) {
@@ -374,8 +375,6 @@ parse_atom_entry (TotemPlParser *parser, xml_node_t *parent)
 			title = node->data;
 		} else if (g_ascii_strcasecmp (node->name, "author") == 0) {
 			//FIXME
-		} else if (g_ascii_strcasecmp (node->name, "logo") == 0) {
-			img = node->data;
 		} else if (g_ascii_strcasecmp (node->name, "link") == 0) {
 			const char *rel;
 
@@ -825,10 +824,10 @@ static TotemPlParserResult
 parse_opml_outline (TotemPlParser *parser, xml_node_t *parent)
 {
 	xml_node_t* node;
-	const char *title, *uri;
 
-	title = uri = NULL;
 	for (node = parent->child; node != NULL; node = node->next) {
+		const char *title, *uri;
+
 		if (node->name == NULL || g_ascii_strcasecmp (node->name, "outline") != 0)
 			continue;
 
