@@ -1339,11 +1339,11 @@ totem_pl_parser_add_uri_valist (TotemPlParser *parser,
 				va_list      var_args)
 {
 	const char *name;
-	char *title, *uri;
+	char *uri;
 	GHashTable *metadata;
 	gboolean is_playlist;
 
-	title = uri = NULL;
+	uri = NULL;
 	is_playlist = FALSE;
 
 	g_object_ref (G_OBJECT (parser));
@@ -1881,7 +1881,7 @@ totem_pl_parser_parse_internal (TotemPlParser *parser,
 					DEBUG(file, g_print ("URI '%s' dual type has type '%s' from data\n", uri, mimetype));
 				}
 				/* If it's _still_ a text/plain, we don't want it */
-				if (mimetype == NULL || strcmp (mimetype, "text/plain") == 0) {
+				if (mimetype != NULL && strcmp (mimetype, "text/plain") == 0) {
 					ret = TOTEM_PL_PARSER_RESULT_IGNORED;
 					g_free (mimetype);
 					mimetype = NULL;
@@ -2413,7 +2413,7 @@ totem_pl_parser_can_parse_from_filename (const char *filename, gboolean debug)
 		(g_mapped_file_get_contents (map),
 		 g_mapped_file_get_length (map), debug);
 
-	g_mapped_file_free (map);
+	g_mapped_file_unref (map);
 
 	return retval;
 }
